export(weighting_spec)
export(step_unknown_eligibility)
export(step_select_within)
export(step_drop_ineligible)
export(step_nonresponse)
export(step_calibrate)
export(step_trim)
export(step_trim_weights)
export(step_trim_calibrated)
export(step_round)
export(step_rescale)
export(step_assert)
export(step_model_calibration)
export(y_model)
export(prep)
export(collect_weights)
export(collect_propensities)
export(collect_step_detail)
export(design_effect)
export(domain_summary)
export(weight_factors)
export(report_weighting)
S3method(print, weighting_spec)
S3method(print, prepped_weighting_spec)
S3method(summary, prepped_weighting_spec)
S3method(plot, prepped_weighting_spec)
S3method(apply_step, step_unknown_eligibility)
S3method(apply_step, step_select_within)
S3method(apply_step, step_drop_ineligible)
S3method(apply_step, step_nonresponse)
S3method(apply_step, step_calibrate)
S3method(apply_step, step_trim)
S3method(apply_step, step_trim_weights)
S3method(apply_step, step_trim_calibrated)
S3method(apply_step, step_round)
S3method(apply_step, step_rescale)
S3method(apply_step, step_assert)
S3method(apply_step, step_model_calibration)
importFrom(stats, glm, binomial, gaussian, poisson, predict, quantile, sd, median, update, model.matrix, qnorm, as.formula)
importFrom(utils, head, browseURL)
importFrom(graphics, hist, abline, barplot, par)
export(bootstrap_weights)
export(bootstrap_estimate)
export(boot_total)
export(boot_mean)
export(as_svydesign)
export(as_svrepdesign)
export(collect_replicate_weights)
S3method(print, weightflow_boot)
export(jackknife_weights)
export(jackknife_estimate)
export(jack_total)
export(jack_mean)
S3method(print, weightflow_jack)
